#!/bin/sh

SCRIPT_PARAMETERS=`echo $2 $3 $4 $5 $6 $7 $8 $9`
if echo $SCRIPT_PARAMETERS | grep -qiw help ; then
        cat <<EOF

Set variables which describe installation environment.
This script should be sourced from the other installation scripts.
If file 'OEM.ini' is not in the current directory it's filepath  '
should be specified as the first script parameter.

  Usage : set_variables oem_ini_file [ parameters ]

  parameters ( case insensetive ) :

  help  - print this help and exit
  V=1   - be verbose : print variables

EOF
        exit 0
fi
if echo $SCRIPT_PARAMETERS | grep -qiw V=1 ; then
	DECHO=echo
else
	DECHO=true
fi

if [ -z "$1" -o "$1" == "." ]; then
	OEM_FILE=OEM.ini
else
	OEM_FILE="$1"
fi

$DECHO "set_variables.sh : pwd=`pwd` OEM_FILE=$OEM_FILE"

### Set VENDOR, VENDOR_UC, VENDOR_LC

VENDOR=`grep '^VENDOR=' $OEM_FILE 2>/dev/null | sed 's/VENDOR=\(.*\)/\1/'`
if [ -z $VENDOR ]; then
	VENDOR="Unknown"
fi
VENDOR_UC=`echo $VENDOR | tr a-z A-Z`
VENDOR_LC=`echo $VENDOR | tr A-Z a-z`

### Set KERNEL_RELEASE

KERNEL_RELEASE=`uname -r`

### Set LINUX_DIST

ISSUE=`cat /etc/issue 2>/dev/null`
LINUX_DIST=
if   ( echo $ISSUE | grep -q "Red Hat Linux release 7.1" ); then
	LINUX_DIST="REDHAT_71"
elif ( echo $ISSUE | grep -q "Red Hat Linux release 7.2" ); then
	LINUX_DIST="REDHAT_72"
elif ( echo $ISSUE | grep -q "Red Hat Linux release 7.3" ); then
	LINUX_DIST="REDHAT_73"
elif ( echo $ISSUE | grep -q "Red Hat Linux release 8" ); then
	LINUX_DIST="REDHAT_8"
elif ( echo $ISSUE | grep -q "Red Hat Linux release 9" ); then
	LINUX_DIST="REDHAT_9"
elif ( echo $ISSUE | grep -q "Fedora Core release 1.92" ); then
	LINUX_DIST="FEDORA_192"
elif ( echo $ISSUE | grep -q "Fedora Core release 2.90" ); then
	LINUX_DIST="FEDORA_290"
elif ( echo $ISSUE | grep -q "Fedora Core release 3" ); then
	LINUX_DIST="FEDORA_300"
elif ( echo $ISSUE | grep -q "SuSE Linux 8.0" ); then
	LINUX_DIST="SUSE_80"
elif ( echo $ISSUE | grep -q "SuSE Linux 8.1" ); then
	LINUX_DIST="SUSE_81"
elif ( echo $ISSUE | grep -q "SuSE Linux 8.2" ); then
	LINUX_DIST="SUSE_82"
elif ( echo $ISSUE | grep -q "SuSE Linux 9.0" ); then
	LINUX_DIST="SUSE_90"
elif ( echo $ISSUE | grep -q "SuSE Linux 9.1" ); then
	LINUX_DIST="SUSE_91"
elif ( echo $ISSUE | grep -q "Linux Mandrake release 8.0" ); then
	LINUX_DIST="MANDRAKE_80"
elif ( echo $ISSUE | grep -q "Mandrake Linux release 8.1" ); then
	LINUX_DIST="MANDRAKE_81"
elif ( echo $ISSUE | grep -q "Mandrake Linux release 8.2" ); then
	LINUX_DIST="MANDRAKE_82"
elif ( echo $ISSUE | grep -q "Mandrake Linux release 9.0" ); then
	LINUX_DIST="MANDRAKE_90"
elif ( echo $ISSUE | grep -q "Mandrake Linux release 10.0" ); then
	LINUX_DIST="MANDRAKE_100"
elif ( echo $ISSUE | grep -q "Caldera OpenLinux 3.1.1" ); then
	LINUX_DIST="CALDERA_311"
elif ( echo $ISSUE | grep -q "Turbolinux.*7.0" ); then
	LINUX_DIST="TURBOLINUX_70"
elif ( echo $ISSUE | grep -q "Turbolinux" ); then
	LINUX_DIST="TURBOLINUX"
fi

if [ -z "$LINUX_DIST" ]; then
	if [ -f /etc/slackware-version ]; then
		SLACKWARE_VERSION=`cat /etc/slackware-version 2>/dev/null`
		if   ( echo $SLACKWARE_VERSION | grep -q "Slackware 8.1" ); then
			LINUX_DIST="SLACKWARE_81"
		else
			LINUX_DIST="SLACKWARE"
		fi
	fi
fi

$DECHO "VENDOR=$VENDOR"
$DECHO "VENDOR_UC=$VENDOR_UC"
$DECHO "VENDOR_LC=$VENDOR_LC"
$DECHO "LINUX_DIST=$LINUX_DIST"
$DECHO "KERNEL_RELEASE=$KERNEL_RELEASE"
